@@ -13,56 +13,52 @@
 # limitations under the License.
 
 import json
-import sys
-
-# different HTTP client libraries for Python 2/3
-if sys.version_info[:2] < (3, 0):
-    from httplib import HTTPConnection
-else:
-    from http.client import HTTPConnection
+import http.client
 
 import nuclio_sdk
+import nuclio_sdk.helpers
 
 
 class Platform(object):
-
-    def __init__(self, kind, namespace='default', connection_provider=None):
+    def __init__(self, kind, namespace="default", connection_provider=None):
         self.kind = kind
         self.namespace = namespace
 
         # connection_provider is used for unit testing
-        self._connection_provider = connection_provider or HTTPConnection
+        self._connection_provider = connection_provider or http.client.HTTPConnection
 
-    def call_function(self, function_name, event, node=None, timeout=None):
+    def call_function(
+        self, function_name, event, node=None, timeout=None, service_name_override=None
+    ):
 
         # get connection from provider
-        connection = self._connection_provider(self._get_function_url(function_name), timeout=timeout)
+        connection = self._connection_provider(
+            self._get_function_url(function_name, service_name_override),
+            timeout=timeout,
+        )
 
         # if the user passes a dict as a body, assume json serialization. otherwise take content type from
         # body or use plain text
         if isinstance(event.body, dict):
             body = json.dumps(event.body)
-            content_type = 'application/json'
+            content_type = "application/json"
         else:
             body = event.body
-            content_type = event.content_type or 'text/plain'
+            content_type = event.content_type or "text/plain"
 
         # use the headers from the event or default to empty dict
         headers = event.headers or {}
-        headers['Content-Type'] = content_type
+        headers["Content-Type"] = content_type
 
         # if no override header, use the name of the function to indicate the target
         # this is needed to cold start a function in case it was scaled to zero
-        headers['X-Nuclio-Target'] = event.headers.get('X-Nuclio-Target', function_name)
+        headers["X-Nuclio-Target"] = event.headers.get("X-Nuclio-Target", function_name)
 
         # let http client determine that
-        headers.pop('Content-Length', None)
+        headers.pop("Content-Length", None)
 
         try:
-            connection.request(event.method,
-                               event.path,
-                               body=body,
-                               headers=headers)
+            connection.request(event.method, event.path, body=body, headers=headers)
 
             # get response from connection
             response = connection.getresponse()
@@ -80,21 +76,26 @@ class Platform(object):
             response_headers[name.lower()] = value
 
         # if content type exists, use it
-        response_content_type = response_headers.get('content-type', 'text/plain')
+        response_content_type = response_headers.get("content-type", "text/plain")
 
         # if content type is json, go ahead and do parsing here. if it explodes, don't blow up
-        if response_content_type == 'application/json':
+        if response_content_type == "application/json":
             response_body = json.loads(response_body)
 
-        return nuclio_sdk.Response(headers=response_headers,
-                                   body=response_body,
-                                   content_type=response_content_type,
-                                   status_code=response.status)
+        return nuclio_sdk.Response(
+            headers=response_headers,
+            body=response_body,
+            content_type=response_content_type,
+            status_code=response.status,
+        )
 
-    def _get_function_url(self, function_name):
+    def _get_function_url(self, function_name, service_name_override=None):
 
         # local envs prefix namespace
-        if self.kind == 'local':
-            return '{0}-{1}:8080'.format(self.namespace, function_name)
+        if self.kind == "local":
+            service_name = service_name_override or "nuclio-{0}-{1}".format(
+                self.namespace, function_name
+            )
         else:
-            return '{0}:8080'.format(function_name)
+            service_name = service_name_override or "nuclio-{0}".format(function_name)
+        return "{0}:8080".format(service_name)
